@@ -1,12 +1,10 @@
 import datetime
-import io
 import json
-import os
+from typing import Union
 
 import requests
-from google.cloud.exceptions import NotFound
 from google.protobuf import timestamp_pb2
-from google.cloud import pubsub_v1, storage, secretmanager, secretmanager_v1
+from google.cloud import pubsub_v1, secretmanager, secretmanager_v1
 from google.cloud import tasks_v2
 from google.cloud import error_reporting
 
@@ -148,118 +146,6 @@ class Tasks:
             return tasks_v2.HttpMethod.GET if self._payload is None else tasks_v2.HttpMethod.POST
 
 
-class Storage:
-    """ Google Cloud Storage Adapter"""
-
-    def __init__(self, bucket_name='expressmoney'):
-        self._bucket_name = bucket_name
-        self.storage_client = storage.Client()
-        self.bucket = self.storage_client.bucket(self._bucket_name)
-
-    def upload_blob(self, source_file_name, destination_blob_name, type_file='pdf'):
-        """Uploads a file to the bucket."""
-        blob = self.bucket.blob(destination_blob_name)
-        blob.upload_from_string(source_file_name, content_type=f'application/{type_file}')
-
-    def delete_blob(self, blob_name):
-        """Deletes a blob from the bucket."""
-        blob = self.bucket.blob(blob_name)
-        blob.delete()
-
-    def get_blob(self, path_to_file):
-        """ Upload a file from the bucket. """
-        blob = self.bucket.blob(path_to_file)
-        try:
-            file = io.BytesIO(blob.download_as_bytes())
-            return file
-        except NotFound:
-            return None
-
-
-class VertexAI:
-    """Google Cloud VertexAI Adapter"""
-
-    REGION = 'us-central1'
-    PROJECT_ID = '1086735462412'
-
-    def __init__(self, endpoint_id, instance_dict: dict, action='predict'):
-        self._action = action
-        self.endpoint_id = endpoint_id
-        self.url = f'https://{self.REGION}-aiplatform.googleapis.com/v1/projects/{self.PROJECT_ID}/locations/' \
-                   f'{self.REGION}/endpoints/{self.endpoint_id}:{action}'
-        self.bearer = self._get_token()
-        self._instance_dict = instance_dict
-        self.__response = None
-
-    @property
-    def _response(self):
-
-        if self.__response is None:
-            # preparing data for google service
-            data = dict()
-            data['instances'] = []
-            data['instances'].append(self._instance_dict)
-
-            headers = {
-                'Content-Type': 'application/json',
-                'Authorization': f'Bearer {self.bearer}',
-            }
-
-            # self.__response = RequestService.request(method='POST', data=data, headers=headers, url=self.url)
-
-            self.__response = requests.post(self.url, json=data, headers=headers)
-
-            if self.__response.status_code != 200:
-                error = f'Fail prediction из VertexAI: {self.__response.status_code}'
-                report.report(error)
-                raise Exception(error)
-
-        return self.__response
-
-    def get_score(self):
-        predictions = self._response
-        predictions = predictions.json().get('predictions')[0]
-        for target_index, target_value in enumerate(predictions['classes']):
-            if target_value == '1':
-                score = predictions.get('scores')[target_index]
-                return score
-
-        raise Exception("Not found target '1' in prediction result")
-
-    def get_explanations(self):
-        if self._action != 'explain':
-            return None
-        target_name = self._response.json().get('explanations')[0].get('attributions')[0].get('outputDisplayName')
-        explanations = self._response.json().get('explanations')[0].get('attributions')[0].get('featureAttributions')
-        multiplier = 1000 if int(target_name) == 1 else -1000
-        explanations = {key: multiplier * value for key, value in explanations.items()}
-        return explanations
-
-    @staticmethod
-    def _get_token():
-        if os.getenv('GAE_APPLICATION'):
-            # when we are in GAE env:
-            metadata_url = 'http://metadata.google.internal/computeMetadata/v1/'
-            metadata_headers = {'Metadata-Flavor': 'Google'}
-            service_account = 'default'
-
-            url = '{}instance/service-accounts/{}/token'.format(
-                metadata_url, service_account)
-
-            # Request an access token from the metadata server.
-            r = requests.get(url, headers=metadata_headers)
-            r.raise_for_status()
-
-            # Extract the access token from the response.
-            access_token = r.json()['access_token']
-        else:
-            # when running locally:
-            stream = os.popen('gcloud auth application-default print-access-token')
-            access_token = stream.read().strip()
-
-        return access_token
-
-
 class Request:
     """Sync http request"""
 
@@ -268,14 +154,14 @@ class Request:
     def __init__(self,
                  service: str = None,
                  path: str = '/',
-                 access_token: str = None,
+                 access_token: Union[str, None] = None,
                  project: str = 'expressmoney',
                  timeout: tuple = (30, 30),
                  ):
         self.__project = project
         self.__service = service
         self.__path = path
-        self.__access_token = str(access_token)
+        self.__access_token = access_token
         self.__timeout = timeout
 
     def run(self, payload: dict = None, update: bool = False):
@@ -292,12 +178,11 @@ class Request:
             response = requests.post(self._uri, json=payload, headers=self._headers, timeout=self.__timeout)
         else:
             response = requests.get(self._uri, headers=self._headers, timeout=self.__timeout)
-        if response.status_code == 403:
-            raise Exception('Service account does not have permission '
-                            'to access the IAP-protected application.')
-        elif response.status_code not in (200, 201):
-            raise Exception('Bad response from application: {!r} / {!r} / {!r}'.format(
-                response.status_code, response.headers, response.text))
+        if response.status_code not in (200, 201):
+            try:
+                raise Exception(f'{response.status_code}:{response.url}:{response.json()}')
+            except Exception:
+                raise Exception(f'{response.status_code}:{response.url}:{response.text}')
         return response
 
     @property
