@@ -20,30 +20,19 @@ class DjangoTasks(adapters.Tasks):
                  queue: str = 'attempts-1',
                  location: str = 'europe-west1',
                  in_seconds: int = None):
-        if not isinstance(user, User):
-            user = User.objects.get(pk=user)
-        access_token = RefreshToken.for_user(user).access_token
+        user = None if user is None else user if isinstance(user, User) else User.objects.get(pk=user)
+        access_token = RefreshToken.for_user(user).access_token if user is not None else None
         super().__init__(service, path, access_token, project, queue, location, in_seconds)
 
 
 class DjangoPubSub(adapters.PubSub):
 
     def __init__(self, topic_id: str, user: Union[None, int, User] = None, project: str = settings.PROJECT):
-        if user:
-            if not isinstance(user, User):
-                user = User.objects.get(pk=user)
-            access_token = RefreshToken.for_user(user).access_token
-        else:
-            access_token = None
+        user = None if user is None else user if isinstance(user, User) else User.objects.get(pk=user)
+        access_token = RefreshToken.for_user(user).access_token if user is not None else None
         super().__init__(topic_id, access_token, project)
 
 
-class DjangoStorage(adapters.Storage):
-    def __init__(self):
-        bucket_name = f'{settings.PROJECT}.appspot.com'
-        super().__init__(bucket_name)
-
-
 class DjangoRequest(Request):
 
     def __init__(self,
@@ -53,8 +42,8 @@ class DjangoRequest(Request):
                  project: str = 'expressmoney',
                  timeout: tuple = (30, 30),
                  ):
-        user = user if isinstance(user, User) else User.objects.get(pk=user)
-        access_token = RefreshToken.for_user(user).access_token if user else None
+        user = None if user is None else user if isinstance(user, User) else User.objects.get(pk=user)
+        access_token = RefreshToken.for_user(user).access_token if user is not None else None
         super().__init__(service, path, access_token, project, timeout)
 
     def _get_authorization(self) -> dict:
